jactorch.utils.grad
===================

.. automodule:: jactorch.utils.grad

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      no_grad_func
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: no_grad_func


